@@ -17,9 +17,8 @@ from .utils import *
 
 async def _get_client(ls: int):
     TonlibClient.enable_unaudited_binaries()
-    client = TonlibClient(ls_index=ls, verbosity_level=1)
+    client = TonlibClient(ls_index=ls)
     await client.init_tonlib()
-    client.tonlib_wrapper.__del__()
     return client
 
 
